@@ -156,16 +156,14 @@ class DataVolume(NamespacedResource):
     def to_dict(self):
         super().to_dict()
         if not self.yaml_file:
-            self.res.update(
-                {
-                    "spec": {
-                        "source": {self.source: {"url": self.url}},
-                        self.api_name: {
-                            "resources": {"requests": {"storage": self.size}},
-                        },
-                    }
+            self.res.update({
+                "spec": {
+                    "source": {self.source: {"url": self.url}},
+                    self.api_name: {
+                        "resources": {"requests": {"storage": self.size}},
+                    },
                 }
-            )
+            })
             if self.access_modes:
                 self.res["spec"][self.api_name]["accessModes"] = [self.access_modes]
             if self.content_type:
@@ -183,17 +181,17 @@ class DataVolume(NamespacedResource):
             if self.source == "upload" or self.source == "blank":
                 self.res["spec"]["source"][self.source] = {}
             if self.hostpath_node:
-                self.res["metadata"].setdefault("annotations", {}).update(
-                    {f"{NamespacedResource.ApiGroup.KUBEVIRT_IO}/provisionOnNode": (self.hostpath_node)}
-                )
+                self.res["metadata"].setdefault("annotations", {}).update({
+                    f"{NamespacedResource.ApiGroup.KUBEVIRT_IO}/provisionOnNode": (self.hostpath_node)
+                })
             if self.multus_annotation:
-                self.res["metadata"].setdefault("annotations", {}).update(
-                    {f"{NamespacedResource.ApiGroup.K8S_V1_CNI_CNCF_IO}/networks": (self.multus_annotation)}
-                )
+                self.res["metadata"].setdefault("annotations", {}).update({
+                    f"{NamespacedResource.ApiGroup.K8S_V1_CNI_CNCF_IO}/networks": (self.multus_annotation)
+                })
             if self.bind_immediate_annotation:
-                self.res["metadata"].setdefault("annotations", {}).update(
-                    {f"{self.api_group}/storage.bind.immediate.requested": "true"}
-                )
+                self.res["metadata"].setdefault("annotations", {}).update({
+                    f"{self.api_group}/storage.bind.immediate.requested": "true"
+                })
             if self.source == "pvc":
                 self.res["spec"]["source"]["pvc"] = {
                     "name": self.source_pvc or "dv-source",
@@ -202,9 +200,9 @@ class DataVolume(NamespacedResource):
             if self.preallocation is not None:
                 self.res["spec"]["preallocation"] = self.preallocation
             if self.delete_after_completion:
-                self.res["metadata"].setdefault("annotations", {}).update(
-                    {f"{self.api_group}/storage.deleteAfterCompletion": (self.delete_after_completion)}
-                )
+                self.res["metadata"].setdefault("annotations", {}).update({
+                    f"{self.api_group}/storage.deleteAfterCompletion": (self.delete_after_completion)
+                })
 
     def wait_deleted(self, timeout=TIMEOUT_4MINUTES):
         """
@@ -219,15 +217,12 @@ class DataVolume(NamespacedResource):
         super().wait_deleted(timeout=timeout)
         return self.pvc.wait_deleted(timeout=timeout)
 
-    def wait(self, timeout=TIMEOUT_10MINUTES, failure_timeout=TIMEOUT_2MINUTES, wait_for_exists_only=False):
-        if wait_for_exists_only:
-            return super().wait(timeout=timeout)
-        else:
-            self._check_none_pending_status(failure_timeout=failure_timeout)
+    def wait(self, timeout=TIMEOUT_10MINUTES, failure_timeout=TIMEOUT_2MINUTES):
+        self._check_none_pending_status(failure_timeout=failure_timeout)
 
-            # If DV's status is not Pending, continue with the flow
-            self.wait_for_status(status=self.Status.SUCCEEDED, timeout=timeout)
-            self.pvc.wait_for_status(status=PersistentVolumeClaim.Status.BOUND, timeout=timeout)
+        # If DV's status is not Pending, continue with the flow
+        self.wait_for_status(status=self.Status.SUCCEEDED, timeout=timeout)
+        self.pvc.wait_for_status(status=PersistentVolumeClaim.Status.BOUND, timeout=timeout)
 
     @property
     def pvc(self):
@@ -275,7 +270,6 @@ class DataVolume(NamespacedResource):
         self,
         timeout=TIMEOUT_10MINUTES,
         failure_timeout=TIMEOUT_2MINUTES,
-        dv_garbage_collection_enabled=False,
         stop_status_func=None,
         *stop_status_func_args,
         **stop_status_func_kwargs,
@@ -286,7 +280,6 @@ class DataVolume(NamespacedResource):
         Args:
             timeout (int):  Time to wait for the DataVolume to succeed.
             failure_timeout (int): Time to wait for the DataVolume to have not Pending/None status
-            dv_garbage_collection_enabled (bool, default: False): if True, expect that DV will disappear after success
             stop_status_func (function): function that is called inside the TimeoutSampler
                 if it returns True - stop the Sampler and raise TimeoutExpiredError
                 Example:
@@ -312,10 +305,8 @@ class DataVolume(NamespacedResource):
                 wait_timeout=timeout,
                 func=lambda: self.exists,
             ):
-                # DV reach success if the status is Succeeded, or if DV garbage collection enabled and the DV does not exist
-                if sample and sample.get("status", {}).get("phase") == self.Status.SUCCEEDED:
-                    break
-                elif sample is None and dv_garbage_collection_enabled:
+                # DV reach to success if the status is succeeded or if the DV does not exist
+                if sample is None or sample.get("status", {}).get("phase") == self.Status.SUCCEEDED:
                     break
                 elif stop_status_func and stop_status_func(*stop_status_func_args, **stop_status_func_kwargs):
                     raise TimeoutExpiredError(
@@ -325,6 +316,7 @@ class DataVolume(NamespacedResource):
                             f" {status_of_dv_str} {sample.status}"
                         )
                     )
+
         except TimeoutExpiredError:
             self.logger.error(f"{status_of_dv_str} {sample.status}")
             raise
